# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.utils.encoding import python_2_unicode_compatible
from django.db import models
from django.utils.translation import ugettext as _
from django.conf import settings

from jmb.core.db.cmsmodels import StatusModel
from cms.models.pluginmodel import CMSPlugin

@python_2_unicode_compatible
class LoginSettings(CMSPlugin, StatusModel):
    slug = models.SlugField(
        max_length=100,
        null=True, blank=True
    )
    classes = models.CharField(
        max_length=100,
        null=True, blank=True
    )
    form = models.CharField(
        max_length=100,
        choices=settings.ORGANIZATION_CMSPLUGIN_LOGIN_FORM_CLASSES,
        default="bxs.people.forms.LoginForm",
    )
    form_template_name = models.CharField(
        max_length=100,
        choices=settings.ORGANIZATION_CMSPLUGIN_LOGIN_FORM_TEMPLATES,
        default="people/cms_plugins/registration/column_login_form.html"
    )
    recovery_password_slug = models.SlugField(
        _("Recovery password page"),
        null=True, blank=True,
        help_text=_("Recovery password page slug")
    )

    def __str__(self):
        return "%s %s" % (('On - ' if self.status else 'Off - '), self.slug)

    class Meta:
        app_label = "organization"

@python_2_unicode_compatible
class RegistrationSettings(CMSPlugin, StatusModel):
    slug = models.SlugField(
        max_length=100,
        null=True, blank=True
    )
    classes = models.CharField(
        max_length=100,
        null=True, blank=True
    )
    sent_from = models.EmailField(
        _('Indirizzo mittente delle mail'),
        default="sender@example.org",
    )
    form = models.CharField(
        max_length=100,
        choices=settings.ORGANIZATION_CMSPLUGIN_REGISTRATION_FORM_CLASSES,
        default="bxs.people.forms.BuyerRegistrationForm",
    )
    form_template_name = models.CharField(
        max_length=100,
        choices=settings.ORGANIZATION_CMSPLUGIN_REGISTRATION_FORM_TEMPLATES,
        default="people/cms_plugins/registration/buyer_registration_form.html"
    )
    registration_done_template = models.CharField(
        max_length=100,
        choices=settings.ORGANIZATION_CMSPLUGIN_REGISTRATION_REGISTRATION_DONE_TEMPLATES,
        default="people/cms_plugins/registration/buyer_registration_done.html"
    )
    activation_done_template = models.CharField(
        max_length=100,
        choices=settings.ORGANIZATION_CMSPLUGIN_REGISTRATION_ACTIVATION_DONE_TEMPLATES,
        default="people/cms_plugins/registration/buyer_activation_done.html"
    )
    email_registration_done_template = models.CharField(
        max_length=100,
        choices=settings.ORGANIZATION_CMSPLUGIN_REGISTRATION_EMAIL_REGISTRATION_DONE_TEMPLATES,
        default="people/cms_plugins/registration/buyer_registration_done_email.html"
    )
    email_activation_done_template = models.CharField(
        max_length=100,
        choices=settings.ORGANIZATION_CMSPLUGIN_REGISTRATION_EMAIL_ACTIVATION_DONE_TEMPLATES,
        default="people/cms_plugins/registration/buyer_activation_done_email.html"
    )
    registration_done_slug = models.SlugField(
        _("Registration done page"),
        help_text=_("Registration done page slug")
    )
    activation_done_slug = models.SlugField(
        _("Activation done page"),
        help_text=_("Activation done page slug")
    )

    def __str__(self):
        return "%s %s" % (('On - ' if self.status else 'Off - '), self.slug)

    class Meta:
        app_label = "organization"

@python_2_unicode_compatible
class RecoveryPasswordSettings(CMSPlugin, StatusModel):
    slug = models.SlugField(
        max_length=100,
        null=True, blank=True
    )
    form = models.CharField(
        max_length=100,
        choices=settings.ORGANIZATION_CMSPLUGIN_PASSWORDRECOVERY_FORM_CLASSES,
        default="jmb.organization.forms.RecoveryPasswordForm",
    )
    sent_from = models.EmailField(
        _('Sender email address'),
        default="info@example.org",
    )
    password_reset_pageslug = models.CharField(
        _('Slug della pagina di reset password (deve essere una pagina esistente)'),
        max_length=200,
        default="password-reset",
    )
    done_message = models.CharField(
        _('Confirm message'),
        max_length=200
    )
    form_template_name = models.CharField(
        max_length=100,
        choices=settings.ORGANIZATION_CMSPLUGIN_PASSWORDRECOVERY_FORM_TEMPLATES,
        default="organization/cms_plugins/recovery_password_form.html"
    )
    done_template_name = models.CharField(
        max_length=100,
        choices=settings.ORGANIZATION_CMSPLUGIN_PASSWORDRECOVERY_DONE_TEMPLATES,
        default="organization/cms_plugins/recovery_password_done.html"
    )
    email_template_name = models.CharField(
        max_length=100,
        choices=settings.ORGANIZATION_CMSPLUGIN_PASSWORDRECOVERY_EMAIL_TEMPLATES,
        default="organization/cms_plugins/recovery_password_email.html"
    )
    redirect_to = models.CharField(
        _("Redirect to"),
        max_length=150,
        null=True, blank=True,
        default='/',
        help_text=_("(Optional) page slug for fallback redirection")
    )

    def __str__(self):
        if self.slug:
            _unicode = self.slug
        else:
            _unicode = "recovery password"
        return "%s - %s" % (
            "On" if self.status else "Off", _unicode
        )

    class Meta:
        app_label = "organization"

@python_2_unicode_compatible
class ResetPasswordSettings(CMSPlugin, StatusModel):

    slug = models.SlugField(
        max_length=100,
        null=True, blank=True
    )
    form_notlogged_in = models.CharField(
        max_length=100,
        choices=settings.ORGANIZATION_CMSPLUGIN_PASSWORDRESET_NOTLOGGEDIN_FORM_CLASSES,
        default="jmb.organization.forms.ResetPasswordForm",
    )
    form_logged_in = models.CharField(
        max_length=100,
        choices=settings.ORGANIZATION_CMSPLUGIN_PASSWORDRESET_LOGGEDIN_FORM_CLASSES,
        default="jmb.organization.forms.SetPasswordFormWOldPW",
    )
    done_message = models.CharField(
        _('Confirm message'),
        max_length=200
    )
    form_template_name = models.CharField(
        max_length=100,
        choices=settings.ORGANIZATION_CMSPLUGIN_PASSWORDRESET_FORM_TEMPLATES,
        default="organization/cms_plugins/reset_password_form.html"
    )
    done_template_name = models.CharField(
        max_length=100,
        choices=settings.ORGANIZATION_CMSPLUGIN_PASSWORDRESET_DONE_TEMPLATES,
        default="organization/cms_plugins/reset_password_done.html"
    )
    email_template_name = models.CharField(
        max_length=100,
        choices=settings.ORGANIZATION_CMSPLUGIN_PASSWORDRESET_EMAIL_TEMPLATES,
        default="organization/cms_plugins/reset_password_email.html"
    )
    sent_from = models.EmailField(
        _('Indirizzo mittente delle mail'),
        default="info@example.org",
    )
    redirect_to = models.CharField(
        _("Redirect to"),
        max_length=150,
        null=True, blank=True,
        default='/',
        help_text=_("(Optional) page slug for fallback redirection")
    )

    def __str__(self):
        if self.slug:
            _unicode = self.slug
        else:
            _unicode = "reset password"
        return "%s - %s" % (
            "On" if self.status else "Off", _unicode
        )

    class Meta:
        app_label = "organization"
